#' @title Documentation of this correlatio package.
#' 
#' @description This R package can help visualizing what is summarized in Pearson's correlation coefficient.
#' 
#' All R packages that have been used in, as well as for developing, this correlatio package, are listed below. Thanks to the many R package developers!
#'
#' @importFrom Rdpack reprompt
#'
#' @name correlatio
#'
#' @references
#' 
#' \insertRef{wickham2016programming}{correlatio}
#' 
#' \insertRef{tibble2023}{correlatio}
#' 
#' \insertRef{rStats}{correlatio}
#' 
#' \insertRef{devtools}{correlatio}
#' 
#' \insertRef{usethis}{correlatio}
#' 
#' \insertRef{roxygen2}{correlatio}
#' 
#' \insertRef{Rdpack}{correlatio}
#' 
NULL

"_PACKAGE"
